@@ -56,7 +56,6 @@ from tests.util import get_search_squeaks
 from tests.util import get_sell_price
 from tests.util import get_squeak_display
 from tests.util import get_squeak_profile
-from tests.util import get_twitter_bearer_token
 from tests.util import import_signing_profile
 from tests.util import make_squeak
 from tests.util import open_peer_connection
@@ -64,7 +63,6 @@ from tests.util import peer_connection
 from tests.util import public_key_from_hex
 from tests.util import send_coins
 from tests.util import set_sell_price
-from tests.util import set_twitter_bearer_token
 from tests.util import subscribe_connected_peers
 from tests.util import subscribe_squeak_ancestor_entries
 from tests.util import subscribe_squeak_entry
@@ -101,18 +99,6 @@ def test_get_sell_price(admin_stub):
     assert price.default_price_msat == 1000000
 
 
-def test_get_twitter_bearer_token(admin_stub):
-    # Get the twitter bearer token
-    bearer_token = get_twitter_bearer_token(admin_stub)
-
-    assert bearer_token == ''
-
-    set_twitter_bearer_token(admin_stub, "new_bearer_token")
-    bearer_token = get_twitter_bearer_token(admin_stub)
-
-    assert bearer_token == "new_bearer_token"
-
-
 def test_get_external_address(admin_stub):
     # Get the external address
     external_address = get_external_address(admin_stub)
@@ -281,6 +267,32 @@ def test_make_reply_squeak(
     ]
 
 
+def test_make_private_squeak(admin_stub, signing_profile_id, recipient_contact_profile_id):
+    make_squeak_content = "This is a private squeak!"
+    make_squeak_hash = make_squeak(
+        admin_stub,
+        signing_profile_id,
+        make_squeak_content,
+        recipient_profile_id=recipient_contact_profile_id,
+    )
+    assert len(make_squeak_hash) == 32 * 2
+
+    # Get the squeak display item
+    get_squeak_display_entry = get_squeak_display(
+        admin_stub, make_squeak_hash)
+    assert get_squeak_display_entry.squeak_hash == make_squeak_hash
+    assert (
+        get_squeak_display_entry.content_str == "This is a private squeak!"
+    )
+    assert get_squeak_display_entry.is_author_known
+    assert get_squeak_display_entry.HasField("author")
+    assert len(
+        get_squeak_display_entry.author.profile_image) > 0
+    assert not get_squeak_display_entry.is_reply
+    assert not bool(get_squeak_display_entry.reply_to)
+    assert len(get_squeak_display_entry.secret_key_hex) == 32 * 2
+
+
 def test_make_signing_profile(admin_stub):
     # Create a new signing profile
     profile_name = "test_signing_profile_name"
